/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var androidPlatform = require('../../lib/cordovaAndroid');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  androidProjPath;

describe('platform-native-android cordova-detection', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    androidProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
  });

  it('should detect cordova-android platform at root of project', function (done) {
      process.chdir(androidProjPath);
      androidPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-android');
        assert.deepEqual(result.platform, 'android');
        assert.deepEqual(result.configXMLPath, path.resolve(androidProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(androidProjPath, 'platforms', 'android'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect cordova-android when below platforms/android/<folder>', function (done) {
      var pathBelowAndroid = path.resolve(androidProjPath, 'platforms', 'android', 'assets');
      process.chdir(pathBelowAndroid);
      androidPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-android');
        assert.deepEqual(result.platform, 'android');
        assert.deepEqual(result.configXMLPath, path.resolve(androidProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(androidProjPath, 'platforms', 'android'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should use folder name where config.xml lives if problem getting Cordova appname from config.xml', function (done) {
      var Fixture = require('ibm-test-fixtures');
      var corrupConfigXMLPath = path.resolve(__dirname, '..', 'fixtures', 'testCordovaProjectCorruptConfigXML.zip');

      //This will be deleted when the after() function runs as it is the same fixture path
      var corruptConfigXMLFixture = new Fixture(corrupConfigXMLPath, fixturePath);
      corruptConfigXMLFixture.clean();
      var androidProjPathAlt = path.resolve(fixturePath, 'testCordovaProjectCorruptConfigXML');

      process.chdir(androidProjPathAlt);
      androidPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'testCordovaProjectCorruptConfigXML');
        assert.deepEqual(result.platformId, 'cordova-android');
        assert.deepEqual(result.platform, 'android');
        assert.deepEqual(result.configXMLPath, path.resolve(androidProjPathAlt, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(androidProjPathAlt, 'platforms', 'android'));
        corruptConfigXMLFixture.delete();
        done();
      }).catch(function (err) {
        corruptConfigXMLFixture.delete();
        done(err);
      });
  }),

  it('should not detect cordova-android when outside project', function (done) {
    process.chdir(__dirname);
    androidPlatform.detect()
    .then(function () {
      assert(false, 'It should not have detected cordova-android outside project');
    }, function () {
      assert(true, 'Should not have detected a project');
      done();
    }).catch(function (err) {
      done(err);
    });
  });
});
