/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */
/*global beforeEach */

var assert = require('assert');
var fs = require('fs');
var glob = require('glob');
var path = require('path');
//private packages
var androidPlatform = require('../../lib/nativeAndroid');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  androidProjPath;
var originalCwd;

describe('platform-native-android native-detection', function () {
  before(function() {
    originalCwd = process.cwd();
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('AndroidNativeProject.zip', fixturePath);

    androidProjPath = path.resolve(fixturePath, 'AndroidNativeProject');
  });

  beforeEach(function() {
    cordovaProject.clean();
  });

  after(function() {
    process.chdir(originalCwd);
    cordovaProject.delete();
  });

  it('should detect native-android platform at root of project, appname pulled from .iml file', function (done) {
    process.chdir(androidProjPath);
    androidPlatform.detect()
    .then(function (result) {
      assert.notEqual(result, undefined);
      assert.deepEqual(result.appName, 'TestNativeProject');
      assert.deepEqual(result.platformId, 'native-android');
      assert.deepEqual(result.platform, 'android');
      assert.deepEqual(result.configXMLPath, undefined);
      assert.deepEqual(result.platformPath, androidProjPath);
      done();
    }).catch(function (err) {
      done(err);
    });
  }),

  it('should detect native-android when below root', function (done) {
    var pathBelowAndroid = path.resolve(androidProjPath, 'app');
    process.chdir(pathBelowAndroid);
    androidPlatform.detect()
    .then(function (result) {
      assert.notEqual(result, undefined);
      assert.deepEqual(result.appName, 'TestNativeProject');
      assert.deepEqual(result.platformId, 'native-android');
      assert.deepEqual(result.platform, 'android');
      assert.deepEqual(result.configXMLPath, undefined);
      assert.deepEqual(result.platformPath, androidProjPath);
      done();
    }).catch(function (err) {
      done(err);
    });
  }),

  it('should not detect cordova-android when outside project', function (done) {
    process.chdir(__dirname);
    androidPlatform.detect()
    .then(function () {
      assert(false, 'It should not have detected native-android outside project');
    }, function () {
      assert(true, 'Should not have detected a project');
      done();
    }).catch(function (err) {
      done(err);
    });
  }),

  it('should detect native-android platform at root of project, .iml not present, appname is set as folder name', function (done) {
    var imlFile = glob.sync('TestNativeProject.iml', {cwd: androidProjPath});
    if(imlFile.length > 0) {
      fs.unlinkSync(path.resolve(androidProjPath, imlFile[0]));
    }
    process.chdir(androidProjPath);
    androidPlatform.detect()
    .then(function (result) {
      assert.notEqual(result, undefined);
      assert.deepEqual(result.appName, 'AndroidNativeProject');
      assert.deepEqual(result.platformId, 'native-android');
      assert.deepEqual(result.platform, 'android');
      assert.deepEqual(result.configXMLPath, undefined);
      assert.deepEqual(result.platformPath, androidProjPath);
      done();
    }).catch(function (err) {
      done(err);
    });
  });
});
