/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var androidPlatform = require('../../lib/nativeAndroid');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  androidProjPath;

describe('platform-native-android parsing', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('AndroidNativeProject.zip', fixturePath);

    cordovaProject.clean();
    androidProjPath = path.resolve(fixturePath, 'AndroidNativeProject');
  });

  after(function() {
    cordovaProject.delete();
  });

  it('should parse native-android platform when provided the root of project', function (done) {
      androidPlatform.parse(androidProjPath)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], 'test.ibm.com.testnativeproject');
        assert.deepEqual(result['app.name'], 'TestNativeProject');
        assert.deepEqual(result['app.version'], '1.0');
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not parse native-android when provided directory other than root', function(done) {
    var androidAppProjPath = path.resolve(androidProjPath, 'app');
    androidPlatform.parse(androidAppProjPath)
    .then(function() {
      assert(false, 'promise should have been rejected');
    }, function(result) {
      assert(true, 'promise was rejected');
      assert.deepEqual(result, undefined);
      done();
    }).catch(function (err) {
      done(err);
    });
  });
});
