/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

var url = require('url');
var os = require('os');
var hasMultipleIPAddresses = getNumIPAddresses() > 1;

// Returns number of ip addresses in our environment
// to make sure we run test that sets server to local profile only if
// we're in an environment without multiple ip addresses
function getNumIPAddresses() {
  var ifaces = os.networkInterfaces();
  return Object.keys(ifaces).reduce(function (numAddresses, dev) {
    return numAddresses + ifaces[dev].reduce(function (numAddresses, details) {
      var isValidIPAddress = details && details.family === 'IPv4' &&
        !details.internal && details.address;
      return isValidIPAddress ? numAddresses + 1 : numAddresses;
    }, 0);
  }, 0);
}

function isURLWithIPAddress(myURL) {
  var parsedURL = url.parse(myURL);
  var ipAddressRegex = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
  return parsedURL.protocol &&
    ipAddressRegex.test(parsedURL.hostname) &&
    parsedURL.port;
}
var nativeData = Object.freeze({
  invalidKeys: ['direct_update_authenticity_public_key',
                'android_security_ignore_file_extensions',
                'android_security_test_web_resources_checksum',
                'ios_security_ignore_file_extensions',
                'ios_security_test_web_resources_checksum',
                'windows10_security_ignore_file_extensions',
                'windows10_security_test_web_resources_checksum',
                'windows8_security_ignore_file_extensions',
                'windows8_security_test_web_resources_checksum',
                'windowsphone8_security_ignore_file_extensions',
                'windowsphone8_security_test_web_resources_checksum',
                'invalidkey'],

  keys: {
    server: {
      initialValue: 'http://10.0.0.1:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    }
  },
  errorWhenNoPropertiesFile: 'NO_CLIENT_PROPERTIES'
});

var nativeWindows8Data = Object.freeze({
  invalidKeys: ['direct_update_authenticity_public_key',
                'android_security_ignore_file_extensions',
                'android_security_test_web_resources_checksum',
                'ios_security_ignore_file_extensions',
                'ios_security_test_web_resources_checksum',
                'windows10_security_ignore_file_extensions',
                'windows10_security_test_web_resources_checksum',
                'windows8_security_ignore_file_extensions',
                'windows8_security_test_web_resources_checksum',
                'windowsphone8_security_ignore_file_extensions',
                'windowsphone8_security_test_web_resources_checksum',
                'invalidkey'],

  keys: {
    server: {
      initialValue: 'http://windows8.com:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    }
  },
  errorWhenNoPropertiesFile: 'NO_CLIENT_PROPERTIES'
});

var nativeWindowsPhone8Data = Object.freeze({
  invalidKeys: ['direct_update_authenticity_public_key',
                'android_security_ignore_file_extensions',
                'android_security_test_web_resources_checksum',
                'ios_security_ignore_file_extensions',
                'ios_security_test_web_resources_checksum',
                'windows10_security_ignore_file_extensions',
                'windows10_security_test_web_resources_checksum',
                'windows8_security_ignore_file_extensions',
                'windows8_security_test_web_resources_checksum',
                'windowsphone8_security_ignore_file_extensions',
                'windowsphone8_security_test_web_resources_checksum',
                'invalidkey'],

  keys: {
    server: {
      initialValue: 'http://windowsphone8.com:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    }
  },
  errorWhenNoPropertiesFile: 'NO_CLIENT_PROPERTIES'
});

var cordovaAllPlatformsData = Object.freeze({
  invalidKeys: ['invalidkey'],
  keys: {
    server: {
      initialValue: 'http://10.0.0.1:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    },
    direct_update_authenticity_public_key: {
      initialValue: '',
      invalidValues: [],
      validValues: [{
        set: 'authenticity_key',
        get: 'authenticity_key'
      }]
    },
    android_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    android_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    },
    ios_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    ios_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    },
    windows10_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    windows10_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    },
    windows8_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    windows8_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    },
    windowsphone8_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    windowsphone8_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    },
  },
  errorWhenNoPropertiesFile: 'NOPLATFORMSDETECTED'
});

var cordovaOnlyIOSData = Object.freeze({
  invalidKeys: ['invalidkey',
                'android_security_ignore_file_extensions',
                'android_security_test_web_resources_checksum',
                'windows10_security_ignore_file_extensions',
                'windows10_security_test_web_resources_checksum',
                'windows8_security_ignore_file_extensions',
                'windows8_security_test_web_resources_checksum',
                'windowsphone8_security_ignore_file_extensions',
                'windowsphone8_security_test_web_resources_checksum'],
  keys: {
    server: {
      initialValue: 'http://10.0.0.1:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    },
    direct_update_authenticity_public_key: {
      initialValue: '',
      invalidValues: [],
      validValues: [{
        set: 'authenticity_key',
        get: 'authenticity_key'
      }]
    },
    ios_security_ignore_file_extensions: {
      initialValue: 'png, jpg, jpeg, gif, mp4, mp3',
      invalidValues: [],
      validValues: [{
        set: 'mp3',
        get: 'mp3'
      }, {
        set: 'png',
        get: 'png'
      }]
    },
    ios_security_test_web_resources_checksum: {
      initialValue: 'false',
      invalidValues: ['invalid'],
      validValues: [{
        set: 'true',
        get: 'true'
      }, {
        set: 'false',
        get: 'false'
      }]
    }
  },
  errorWhenNoPropertiesFile: 'NOPLATFORMSDETECTED'
});

var cordovaNoPlatformsData = Object.freeze({
  invalidKeys: ['invalidkey',
                'android_security_ignore_file_extensions',
                'android_security_test_web_resources_checksum',
                'ios_security_ignore_file_extensions',
                'ios_security_test_web_resources_checksum',
                'windows10_security_ignore_file_extensions',
                'windows10_security_test_web_resources_checksum',
                'windows8_security_ignore_file_extensions',
                'windows8_security_test_web_resources_checksum',
                'windowsphone8_security_ignore_file_extensions',
                'windowsphone8_security_test_web_resources_checksum'],
  keys: {
    server: {
      initialValue: 'http://10.0.0.1:9080',
      invalidValues: ['asdfInvalidServer', 'http://invalidnoport.com'],
      validValues: [{
        set: 'https://example.com:123',
        get: 'https://example.com:123'
      },
      !hasMultipleIPAddresses ? {
        set: 'local',
        get: isURLWithIPAddress
      } : undefined,
      {
        set: 'remote',
        get: 'http://latestmfp.haifa.ibm.com:9080'
      },
      {
        set: 'http://総務省.jp:9080',
        get: 'http://xn--lhr645fjve.jp:9080'
      },
      {
        set: 'idnServer',
        get: 'http://xn--orn-ooa.info:123'
      }]
    },
    runtime: {
      initialValue: 'mfp',
      invalidValues: ['$NotAlphanumeric!'],
      validValues: [{
        set: 'alphanumeric',
        get: 'alphanumeric'
      }]
    },
    language_preferences: {
      initialValue: 'en',
      invalidValues: [],
      validValues: [{
        set: 'en,esp',
        get: 'en,esp'
      }]
    },
    direct_update_authenticity_public_key: {
      initialValue: '',
      invalidValues: [],
      validValues: [{
        set: 'authenticity_key',
        get: 'authenticity_key'
      }]
    }
  },
  errorWhenNoPropertiesFile: 'NOPLATFORMSDETECTED'
});

module.exports.androidNativeTestData = nativeData;
module.exports.iOSNativeTestData = nativeData;
module.exports.windows10NativeTestData = nativeData;
module.exports.windows8NativeTestData = nativeWindows8Data;
module.exports.windowsPhone8NativeTestData = nativeWindowsPhone8Data;
module.exports.cordovaAllPlatformsData = cordovaAllPlatformsData;
module.exports.cordovaOnlyIOSData = cordovaOnlyIOSData;
module.exports.cordovaNoPlatformsData = cordovaNoPlatformsData;
