/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */
/*global beforeEach, afterEach */
var assert = require('assert');
var fs = require('fs');
var mockery = require('mockery');
var path = require('path');
var Q = require('q');
var findExtensions = require('pluggington');
var getTestFixture = require('mdo-test-resources');

describe('app export', function () {
	this.timeout(50000);

	var mdoApp;
    var fixturePath;
	var fixtureProject;
	
	before(function() {
		global.MDO_MAIN_EXTENSIONS_PATH =
		  path.join(__dirname, '../../mfpdev-cli/node_modules');

		mockery.enable({
			useCleanCache: true,
			warnOnUnregistered: false,
			warnOnReplace: true
		});      
	  
		var serverDetailsMock = {
			getApplication: function () {
				var d = Q.defer();
				d.resolve({
					descriptor: {
						"applicationKey": {
							"version": "1.0.0",
							"clientPlatform": "android",
							"packageName": "com.test"
						},
						"displayName": "TestApp"
					}
				});		
				return d.promise;
			},
			getConfidentialClients: function () {
				var d = Q.defer();
				d.resolve({
					clients: []
				});		
				return d.promise;
			},
			getCertificate: function () {

			},
			getServerDetails: function () {
				var d = Q.defer();
				d.resolve({
					runtime: 'mfp',
					serverProfile: {
						host: 'templocalhost',
						protocol: 'http',
						port: '9080'
					},
				});
				return d.promise;
			},      
			profileIO: {
				getServerProfiles: function (cc, dd) {
					var d = Q.defer();
					d.resolve({
						servers: {
							"icpa-mobile-server" : {
								'protocol': "http",
								'host': "templocalhost",
								'port': "9080",
								"ipAddress": "1.2.3.4"         
							}
						}
					});
					return d.promise;
				},
				handleLocalHost: function () {
					var d = Q.defer()
					d.resolve();
					return d.promise;
				}
			}
		}		
		mockery.registerMock('mdo-server-support', serverDetailsMock);
		mdoApp = require('../lib/index.js');
	});

	it('should contribute a mdo.cli.app.actions extension', function() {
		var extensions = findExtensions(path.resolve(__dirname, '..', '..'), 'mdo.cli.app.actions');
	
		assert.notEqual(extensions, undefined, 'There should be a mdo.cli.app.actions extension here');
	
		var foundCommand = false;
		extensions.forEach(function(commandExtension) {
		  if (commandExtension.name === "export") {
			foundCommand = true;
		  }
		});
	
		assert.equal(foundCommand, true, "I didn't find the app command extension!");
	});	
   
	
	it('test export command in client app', function(done) {
		fixturePath = path.resolve(process.cwd(), 'test', 'fixtures');
		fixtureProject = getTestFixture('AndroidNativeProject.zip', fixturePath);

		fixtureProject.clean();
		var projPath = path.resolve(fixturePath, 'AndroidNativeProject');
		process.chdir(projPath);
		mdoApp.run(['export', "icpa-mobile-server"]).then(function () {
			assert(fs.existsSync(path.join(projPath, 'mfpconfig', 'app_config.json')), "app_config.json is not created");
			done();
		}).fail(function (err) {
			done(err);
		}).catch(function (err) {
			done(err);
		});
	});  

});

