/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

var assert = require('assert');
var errors = require('mdo-errors');
var previewCordova = require('../lib/previewCordova.js');
var path = require('path');
var exec = require('mdo-exec').run;

var testFixtures = require('mdo-test-resources');
var fixture;
var fixturesPath;
var cordovaProjectPath;
var origCwd;

function getTestProject() {
  fixturesPath = path.resolve(__dirname, 'fixtures');
  cordovaProjectPath = path.resolve(__dirname, 'fixtures', 'CordovaAndroidiOSWindows');
  fixture = testFixtures('CordovaAndroidiOSWindows.zip', fixturesPath);
  fixture.clean();
}

function errorsEqual(err1, err2) {
  return err1 && err2 ? err1.errno === err2.errno : false;
}

function testForError(expectedError, commandArgs, dir, done) {
  process.chdir(dir);
  previewCordova.run(commandArgs).then(function() {
    assert(false, 'Promise should be rejected');
  }).fail(function(error) {
    assert(errorsEqual(error, expectedError), 'Error is ' + expectedError);
  }).done(function() {
    done();
  });
}

describe('mdo-app-preview', function () {
  before(function(done) {
    global.MDO_MAIN_EXTENSIONS_PATH = path.join(__dirname,
        '/../../mfpdev-cli/node_modules');
    getTestProject();
    origCwd = process.cwd();
    done();
  });

  after(function(done) {
    fixture.delete();
    process.chdir(origCwd);
    done();
  });

  it('Error if cordova does not exist', function (done) {
    var expectedError = errors.getError('CORDOVANOTINSTALLED');
    exec('cordova', ['-v']).then(function () {
      assert(true);
      done();
    }, function() {
      testForError(expectedError, ['ios'], cordovaProjectPath, done);
    });
  });

  it('Error if run outside of a cordova project', function (done) {
    var expectedError = errors.getError('NOPLATFORMSDETECTED');
    testForError(expectedError, [], fixturesPath, done);
  });

  it('Error if more than one watch mode specified', function (done) {
    var expectedError = errors.getError('MORE_THAN_ONE_MODE_SPECIFIED');
    testForError(expectedError, ['ios', '-wc', '-s'], cordovaProjectPath, done);
  });

  it('Error if invalid preview type', function (done) {
    var expectedError = errors.getError('INVALID_PREVIEW_TYPE');
    testForError(expectedError, ['--type', 'bad_type'], cordovaProjectPath,
                 done);
  });

  it('Error if no platform specified', function (done) {
    var expectedError = errors.getError('NO_PLATFORM_SPECIFIED');
    testForError(expectedError, ['--type', 'mbs'], cordovaProjectPath, done);
  });

});
