/*
	Licensed Material - Property of IBM

	(C) Copyright 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */
/*global beforeEach, afterEach */
var assert = require('assert');
var mockery = require('mockery');
var path = require('path');
var Q = require('q');
//private
var getTestFixture = require('mdo-test-resources');
var cordovaSupport = require('mdo-cordova-support');

describe('app encrypt, encrypt fails', function () {
  this.timeout(10000);
    var fixturePath,
        fixtureProject,
        encrypt,
        encryptPassed,
        encryptPlatforms,
        returnCode = -1;


    global.MDO_MAIN_EXTENSIONS_PATH = path.join(__dirname, '..', '..', 'mfpdev-cli', 'node_modules');

    before(function () {
      encryptPlatforms = [];
      encryptPassed = false;

      fixturePath = path.resolve(__dirname, 'fixtures');
      fixtureProject = getTestFixture('CordovaProject.zip', fixturePath);
      fixtureProject.clean();
    });

    beforeEach(function () {
        mockery.enable({
            useCleanCache: true,
            warnOnUnregistered: false,
            warnOnReplace: false
        });

        var cordovaSupportMock = {
          encryptWWWFolder: failureFunction,
          detect: cordovaSupport.detect,
          parse: cordovaSupport.parse
        };
        mockery.registerMock('mdo-cordova-support', cordovaSupportMock);
        encrypt = require('../lib/index');
    });

    afterEach(function () {
        encryptPlatforms = [];
        encryptPassed = false;
    });
    after(function () {
      fixtureProject.delete();
      mockery.disable();
    });


    it('should not perform encrypt should fail with -1 exit code', function (done) {
        var projPath = path.resolve(fixturePath, 'CordovaProject');

        process.chdir(projPath);

        //Set return code to be -2 to simulate platform version error in checksum code
        returnCode = -1;

        encrypt.run([])
        .then(function () {
          assert(false, 'should not have entered success function');
        },function (err) {
          assert.notDeepEqual(err, undefined, 'error should not be undefined');
          assert.deepEqual(err.errno, 255, 'error number should be 255');
          assert.deepEqual(err.code, 'ERRORDURINGEXTERNALSCRIPT', 'error code should be ERRORDURINGEXTERNALSCRIPT');
          assert.deepEqual(encryptPassed, false, 'encrypt should have failed');
          done();
        }).catch(function (err) {
          done(err);
        });
    }),

    it('should not perform encrypt should fail with 1 exit code', function (done) {
        var projPath = path.resolve(fixturePath, 'CordovaProject');

        process.chdir(projPath);

        //Set return code to be 254 to simulate platform version error in checksum code
        returnCode = 1;

        encrypt.run([])
        .then(function () {
          assert(false, 'should not have entered success function');
        },function (err) {
          assert.notDeepEqual(err, undefined, 'error should not be undefined');
          assert.deepEqual(err.errno, 255, 'error number should be 255');
          assert.deepEqual(err.code, 'ERRORDURINGEXTERNALSCRIPT', 'error code should be ERRORDURINGEXTERNALSCRIPT');
          assert.deepEqual(encryptPassed, false, 'encrypt should have failed');
          done();
        }).catch(function (err) {
          done(err);
        });
    });

    function failureFunction () {
      return createReturnPromise(true, {
        code: returnCode
      });
    }

    function createReturnPromise(reject, errObj) {
      var d = Q.defer();
      if(reject) {
        d.reject(errObj);
      } else {
        d.resolve();
      }

      return d.promise;
    }
});
