/*
	Licensed Material - Property of IBM

	(C) Copyright 2015, 2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var browserPlatform = require('../../lib/cordovaBrowser');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  browserProjPath;

describe('platform-native-browser cordova-detection', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    browserProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
  });

  it('should detect cordova-browser platform at root of project', function (done) {
      process.chdir(browserProjPath);
      browserPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-browser');
        assert.deepEqual(result.platform, 'browser');
        assert.deepEqual(result.configXMLPath, path.resolve(browserProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(browserProjPath, 'platforms', 'browser'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect cordova-browser when below platforms/browser/<folder>', function (done) {
      var pathBelowBrowser = path.resolve(browserProjPath, 'platforms', 'browser', 'cordova');
      process.chdir(pathBelowBrowser);
      browserPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-browser');
        assert.deepEqual(result.platform, 'browser');
        assert.deepEqual(result.configXMLPath, path.resolve(browserProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(browserProjPath, 'platforms', 'browser'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should use folder name where config.xml lives if problem getting Cordova appname from config.xml', function (done) {
      var Fixture = require('ibm-test-fixtures');
      var corrupConfigXMLPath = path.resolve(__dirname, '..', 'fixtures', 'testCordovaProjectCorruptConfigXML.zip');

      //This will be deleted when the after() function runs as it is the same fixture path
      var corruptConfigXMLFixture = new Fixture(corrupConfigXMLPath, fixturePath);
      corruptConfigXMLFixture.clean();
      var browserProjPathAlt = path.resolve(fixturePath, 'testCordovaProjectCorruptConfigXML');

      process.chdir(browserProjPathAlt);
      browserPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'testCordovaProjectCorruptConfigXML');
        assert.deepEqual(result.platformId, 'cordova-browser');
        assert.deepEqual(result.platform, 'browser');
        assert.deepEqual(result.configXMLPath, path.resolve(browserProjPathAlt, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(browserProjPathAlt, 'platforms', 'browser'));
        corruptConfigXMLFixture.delete();
        done();
      }).catch(function (err) {
        corruptConfigXMLFixture.delete();
        done(err);
      });
  }),

  it('should not detect cordova-browser when outside project', function (done) {
    process.chdir(__dirname);
    browserPlatform.detect()
    .then(function () {
      assert(false, 'It should not have detected cordova-browser outside project');
    }, function () {
      assert(true, 'Should not have detected a project');
      done();
    }).catch(function (err) {
      done(err);
    });
  });
});
