/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');

//private packages
var browserPlatform = require('../../lib/nativeBrowser');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  nativeProject,
  browserProjPath;

describe('platform-native-browser native-detect', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    nativeProject = getTestFixture('browserNativeProject.zip', fixturePath);

    nativeProject.clean();
    browserProjPath = path.resolve(fixturePath, 'browserNativeProject', 'src', 'main', 'webapp');
  });

  after(function() {
    nativeProject.delete();
  });

  it('should detect native-browser info in index file', function (done) {
      process.chdir(browserProjPath);
      browserPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'DemoWebApp');
        assert.deepEqual(result.platformId, 'native-browser');
        assert.deepEqual(result.platform, 'browser');
        assert.deepEqual(result.platformPath, browserProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-browser when below root if ibm-mfp-web-sdk exists', function (done) {
      var pathBelowbrowser = path.resolve(browserProjPath, 'js');
      process.chdir(pathBelowbrowser);
      browserPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'DemoWebApp');
        assert.deepEqual(result.platformId, 'native-browser');
        assert.deepEqual(result.platform, 'browser');
        assert.deepEqual(result.platformPath, browserProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not detect native-browser when outside project', function (done) {
      process.chdir(__dirname);
      browserPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected native-browser outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
