/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');

//private packages
var browserPlatform = require('../../lib/nativeBrowser');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
    nativeProject,
    browserProjPath;

describe('platform-native-browser test parsing', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    nativeProject = getTestFixture('browserNativeProject.zip', fixturePath);

    nativeProject.clean();
    browserProjPath = path.resolve(fixturePath, 'browserNativeProject', 'src', 'main', 'webapp');
  });

  after(function() {
    nativeProject.delete();
  });

  it('should parse native-browser platform when provided the root of project', function (done) {
      browserPlatform.parse(browserProjPath)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], 'com.sampletwo.bankApp2');
        assert.deepEqual(result['app.name'], 'DemoWebApp');
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should return empty app id and name for native-browser when it cannot find the file to parse', function (done) {
      browserPlatform.parse(__dirname)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], '');
        assert.deepEqual(result['app.name'], '');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
