/*
	Licensed Material - Property of IBM

	(C) Copyright 2015 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

var assert = require('assert');
var path = require('path');
var findExtensions = require('pluggington');
var _getAllExtensions = findExtensions._getAllExtensions;

describe('mdo-cmd-adapter', function() {
  it('should contribute a mdo.cli.commands extension', function() {
    var extensions = findExtensions(path.resolve(__dirname, '..', '..'), 'mdo.cli.commands');

    assert.notEqual(extensions, undefined, 'There should be a mdo.cli.commands extension here');

    var foundCommand = false;
    extensions.forEach(function(commandExtension) {
      if (commandExtension.name === "adapter") {
        foundCommand = true;

        assert.notEqual(commandExtension.export.run, undefined, "adapter command extension does not export a run function!");
        assert.notEqual(commandExtension.export.help, undefined, "adapter command extension does not export a help function!");
      }
    });

    assert.equal(foundCommand, true, "I didn't find the adapter command extension!");
  });

  it('should validate all mdo.cli.adapter.actions extensions', function() {
    var extensions = _getAllExtensions(path.resolve(__dirname, '..', '..'));
    var adapterActionsExtensions = extensions['mdo.cli.adapter.actions'];
    adapterActionsExtensions.forEach(function(extension) {
      assert(extension.name && extension.name !== '', 'mdo.cli.adapter.actions extension at ' + extension._path + ' does not specify a name.');
      assert(extension.export.run, 'mdo.cli.adapter.actions extension at ' + extension._path + ' does not export a run function.');
      assert(extension.export.getHelpFilePath, 'mdo.cli.adapter.actions extension at ' + extension._path + ' does not export a get help file path function.');
    });
  });
});
