'use strict';

var assert = require('assert');
var path = require('path');
var findExtensions = require('pluggington');
var _getAllExtensions = findExtensions._getAllExtensions;
var mdoApp = require('../lib/index.js');
var errors = require('mdo-errors');

function testForError(expectedError, commandArgs, done) {
  mdoApp.run(commandArgs).then(function() {
    assert(false, 'Promise should be rejected');
  }).fail(function(error) {
    assert(errorsEqual(error, expectedError), 'Error is ' + expectedError);
  }).done(function() {
    done();
  });
}

function errorsEqual(err1, err2) {
  return err1 && err2 ? err1.errno === err2.errno : false;
}

describe('mdo-cmd-app', function() {

  before(function(done) {
    global.MDO_MAIN_EXTENSIONS_PATH =
      path.join(__dirname, '../../mfpdev-cli/node_modules');
    done();
  });

  it('should contribute a mdo.cli.commands extension', function() {
    var extensions = findExtensions(path.resolve(__dirname, '..', '..'), 'mdo.cli.commands');

    assert.notEqual(extensions, undefined, 'There should be a mdo.cli.commands extension here');

    var foundCommand = false;
    extensions.forEach(function(commandExtension) {
      if (commandExtension.name === "app") {
        foundCommand = true;
      }
    });

    assert.equal(foundCommand, true, "I didn't find the app command extension!");
  });

  it('should finda a valid mdo.cli.app.actions extension', function() {
    var extensions = findExtensions(__dirname, 'mdo.cli.app.actions');

    assert.notEqual(extensions, undefined, 'There should be a mdo.cli.app.actions extension here');

    var foundExtension = false;
    extensions.forEach(function(extension) {
      if (extension.name === "GoodAction") {
        foundExtension = true;

        assert.notEqual(extension.export.run, undefined, "Did not find a run function in this extension");
        assert.notEqual(extension.export.help, undefined, "Did not find a help function in this extension");
      }
    });

    assert.equal(foundExtension, true, "I didn't find the app action extension!");
  });

  it('should validate all mdo.cli.app.actions extensions', function() {
    var extensions = _getAllExtensions(path.resolve(__dirname, '..', '..'));
    var appActionsExtensions = extensions['mdo.cli.app.actions'];

    appActionsExtensions.forEach(function(extension) {
      assert(extension.name && extension.name !== '', 'mdo.cli.app.actions extension at ' + extension._path + ' does not specify a name.');
      assert(extension.export.run, 'mdo.cli.app.actions extension at ' + extension._path + ' does not export a run function.');
      assert(extension.export.help, 'mdo.cli.app.actions extension at ' + extension._path + ' does not export a help function.');
    });
  });

  it('Command errors out if missing an app action', function(done) {
    var expectedError = errors.getError('MISSINGACTION');
    testForError(expectedError, [], done);
  });

  it('Command errors out if invalid app action', function(done) {
    var expectedError = errors.getError('INVALIDACTION');
    testForError(expectedError, ['invalidAction'], done);
  });
});
