'use strict';

var assert = require('assert');
var path = require('path');
var findExtensions = require('pluggington');
var _getAllExtensions = findExtensions._getAllExtensions;

describe('mdo-cmd-info', function() {
  it('should contribute a mdo.cli.commands extension', function() {
    var extensions = findExtensions(path.resolve(__dirname, '..', '..'), 'mdo.cli.commands');

    assert.notEqual(extensions, undefined, 'There should be a mdo.cli.commands extension here');

    var foundInfoCommand = false;
    extensions.forEach(function(commandExtension) {
      if (commandExtension.name === "info") {
        foundInfoCommand = true;
      }
    });

    assert.equal(foundInfoCommand, true, "I didn't find the info command extension!");
  });

  it('should contribute a mdo.cli.help extension', function() {
    var extensions = _getAllExtensions(path.resolve(__dirname, '..', '..'));
    var helpExtensions = extensions['mdo.cli.help'];

    var foundInfoHelpExtension = false;

    helpExtensions.forEach(function(extension) {
      if (extension._path.indexOf('mdo-cmd-info/package.json') > -1) {
        foundInfoHelpExtension = true;
      }
    });

    assert(foundInfoHelpExtension, "didn't find the info command's help extension");
  });

  it('validate all mdo.cli.info extensions', function() {
    var extensions = findExtensions(path.resolve(__dirname, '..', '..'), 'mdo.cli.info');

    extensions.forEach(function (extension) {
      assert.notEqual(extension.export.printInfo, undefined,
        "Did not find a printInfo function in extension named: " + extension.name
      );
    }
    );
  });

  it('should find a good test extension to mdo.cli.info', function() {
    var extensions = findExtensions(__dirname, "mdo.cli.info");

    var foundGoodExtension = false;

    extensions.forEach(function(extension) {
      if (extension.name === "GoodExtension") {
        foundGoodExtension = true;
        assert.notEqual(extension.export.printInfo, undefined, "Did not find expected printInfo function");
      }
    });

    assert(foundGoodExtension, "didn't find the good info extension");
  });

  it('should find a bad test extension to mdo.cli.info', function() {
    var extensions = findExtensions(__dirname, "mdo.cli.info");

    var foundBadExtension = false;

    extensions.forEach(function(extension) {
      if (extension.name === "BadExtension") {
        foundBadExtension = true;
        assert.equal(extension.export.printInfo, undefined, "Found an unexpected printInfo function");
      }
    });

    assert(foundBadExtension, "didn't find the bad info extension");
  });
});
