'use strict';

var assert = require('assert');
var path = require('path');
var fs = require('fs');

// Private modules
var server = require('../../lib/index.js');
global.MDO_MAIN_EXTENSIONS_PATH = path.join(__dirname, '../../../mfpdev-cli/node_modules');
global.MDO_CLI_FULL_VERSION = require('../../../mfpdev-cli/package.json').version + '_mdo-cmd-server';

var HOME = process.env[(process.platform === 'win32') ? 'USERPROFILE' : 'HOME'];
var IBM_HOME = path.join(HOME, '.ibm');
var MFP_HOME = path.join(IBM_HOME, 'mobilefirst');
var versionPath = path.join(MFP_HOME, global.MDO_CLI_FULL_VERSION);
var profilePath = path.join(versionPath, 'server_profiles.json');


describe('mdo server console command', function () {
  this.timeout(5000);

  before(function(done){
    if (fs.existsSync(profilePath)) {
      try {
        fs.unlinkSync(profilePath);
      }
      catch (err) {
        assert(false, 'cannot delete server_profile.json');
      }
    }
    done();
  });

  it('Run server console remoteserver3 profile does not exist', function (done) {
    server.run(['console remoteserver3'])
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (rsp) {
        assert(
          rsp.errno === 126,
          'Error code: ' + rsp
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('Run invalid args error test', function (done) {
    server.run(['console', 'remoteserver2', 'demo'])
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (rsp) {
        assert(
          rsp.errno === 130,
          'Error code: ' + rsp
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('Run invalid server name error test', function (done) {
    server.run(['console', 'remote server3'])
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (rsp) {
        assert(
          rsp.errno === 120,
          'Error code: ' + rsp
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

});
