/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

/*jshint -W030 */

// Public packages
var assert = require('assert');
var path = require('path');
var fs = require('fs');

// Private packages
var cordovaSupport = require('../../lib/index');
var exec = require('mdo-exec');

var cordovaInstalled;

describe('Testing mdo-cordova-support for Cordova Prepare',
    function () {

      var getTestFixture = require('mdo-test-resources');

      var fixturePath,
        cordovaProject,
        cordovaProjPath;

      before(function() {
        fixturePath = path.resolve(__dirname, '..', 'fixtures');
        cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

        cordovaProject.clean();
        cordovaProjPath = path.resolve(fixturePath, 'CordovaProject');
      });

      after(function() {
        cordovaProject.delete();
        // fs.unlinkSync(fixturePath);
      });

        before(
            function(done) {
                exec.run('cordova', ['-v']).done(
                    function () {
                        cordovaInstalled = true;
                        done();
                    },
                    function () {
                        console.log('Cordova is not installed. Tests for Cordova prepare will not be executed.');
                        cordovaInstalled = false;
                        done();
                    }
                );
            }
        );

        it('Prepare should be called successfully',
            function (done) {
                var testProjPath;
                var indexPath;
                var now;
                var indexContent;

                if (!cordovaInstalled) {
                    done();
                    return;
                }

                testProjPath =
                  path.resolve(fixturePath, 'CordovaProject');
                process.chdir(testProjPath);
                indexPath = path.resolve('www', 'index.html');
                now = (new Date()).getTime();
                fs.writeFileSync(indexPath, now);

                cordovaSupport.prepare().then(
                    function () {
                        indexContent = fs.readFileSync(indexPath);

                        if (indexContent.toString() === now.toString())
                            assert(true, 'Prepare did not return an error code as expected.');
                        else
                            assert(false, 'Prepare failed to copy www content');

                        done();
                    },
                    function (err) {
                        assert(false, 'Prepare returned an error when it should not have: ' + err.stdErr);
                        done();
                    }
                ).fail(function(err){
                  done(err);
                });

            }
        );

        it('Prepare should not be called successfully',
            function (done) {
                var testProjPath;

                if (!cordovaInstalled) {
                    done();
                    return;
                }

                testProjPath = path.resolve(__dirname, '..');
                process.chdir(testProjPath);

                cordovaSupport.prepare().then(
                    function () {
                        assert(false, 'Prepare should have returned an error.');
                        done();
                    },
                    function () {
                        assert(true, 'Prepare returned an error as expected.');
                        done();
                    }
                ).fail(function(err){
                  done(err);
                });
            }
        );

    }
);
