/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var fs = require('fs');
var path = require('path');
//private packages
var cordovaSupport = require('../../lib/index');

describe('mdo-cordova-support testDetection', function () {
  var getTestFixture = require('mdo-test-resources');

  var fixturePath,
    cordovaProject,
    cordovaProjPath;

  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    cordovaProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
    // fs.unlinkSync(fixturePath);
  });

  it('should detect cordova config.xml at root of project', function (done) {
      try {
          fs.statSync(cordovaProjPath);
      } catch (err) {
          assert(false, 'CordovaProject is missing');
      }
      process.chdir(cordovaProjPath);
      cordovaSupport.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result, path.resolve(cordovaProjPath, 'config.xml'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect cordova config.xml when below root', function (done) {
      var pathBelowCordova = path.resolve(cordovaProjPath, 'platforms');
      process.chdir(pathBelowCordova);
      cordovaSupport.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result, path.resolve(cordovaProjPath, 'config.xml'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not detect cordova config.xml when outside project', function (done) {
      process.chdir(__dirname);
      cordovaSupport.detect()
      .then(function () {
        assert(false, 'It should not have detected config.xml outside project');
      }, function () {
        assert(true, 'Should not have detected a config.xml');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
