/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var fs = require('fs');
var path = require('path');
//private packages
var cordovaSupport = require('../../lib/index');

describe('mdo-cordova-support test parsing', function () {
  var getTestFixture = require('mdo-test-resources');

  var fixturePath,
    cordovaProject,
    cordovaProjPath;

  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    cordovaProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
    // fs.unlinkSync(fixturePath);
  });

  it('should parse cordova config.xml', function (done) {
      try {
          fs.statSync(cordovaProjPath);
      } catch (err) {
          assert(false, 'testCordovaProject config.xml is missing');
          done(err);
      }
      cordovaSupport.parse(cordovaProjPath)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.equal(result['app.description'], "A sample Apache Cordova application that responds to the deviceready event.");
        assert.deepEqual(result['app.dotId'], 'io.cordova.hellocordova');
        assert.deepEqual(result['app.mainfile'], 'index.html');
        assert.deepEqual(result['app.name'], 'HelloCordova');
        assert.deepEqual(result['app.version'], '0.0.1');
        assert.deepEqual(result['author.email'], 'dev@cordova.apache.org');
        assert.deepEqual(result['author.href'], 'http://cordova.io');
        assert.deepEqual(result['author.name'], 'Apache Cordova Team');
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should fail when passed directory without config.xml file', function (done) {
      var nonExistentPath = path.resolve(__dirname, '..', 'testCordovaProject', 'nonExistent');
      try {
          fs.statSync(nonExistentPath);
          assert(false, 'testCordovaProject/nonExistent exists? How?');
      } catch (err) {
          assert(true, 'testCordovaProject/nonExistent should not exist');
      }
      cordovaSupport.parse(nonExistentPath)
      .then(function () {
        assert(false, 'should not enter success function');
      }, function () {
        assert(true, 'successfully entered error function');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
