'use strict';

// Public modules
var assert = require('assert');

// Private modules
var exec = require('../../mdo-exec');
var consts = require('../lib/consts');

describe('mdo-exec', function () {
  it('Ensure error occurs with no cmd, but with arguments', function (done) {
    var def;

    def = exec.run('', ['-v']);

    def.done(
      function(data) {
        assert(false, 'Expected error, but instead got: ' + data.stdOut);
        done();
      },
      function(err) {
        assert(true, 'Expected error received: ' + err.description);
        done();
      }
    );
  });

  it('Ensure error occurs with no arguments', function (done) {
    var def;

    def = exec.run();

    def.done(
      function(data) {
        assert(false, 'Expected error, but instead got: ' + data.stdOut);
        done();
      },
      function(err) {
        assert(true, 'Expected error received: ' + err.description);
        done();
      }
    );
  });

  it('Ensure run successfully runs a command.', function (done) {
    var def;

    if (process.platform === consts.WIN)
      def = exec.run('dir');
    else
      def = exec.run('ls');

    def.done(
      function (data) {
        assert(true, 'Got standard output as expected: ' + data.stdOut);
        done();
      },
      function (err) {
        assert(false, 'Did not expect error, but got: ' + err.description);
        done();
      }
    );
  });
});
