/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var iosPlatform = require('../../lib/cordovaIOS');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  iosProjPath;

describe('platform-native-ios cordova-detect', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    iosProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
  });
  
  it('should detect cordova-ios platform at root of project', function (done) {
      process.chdir(iosProjPath);
      iosPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-ios');
        assert.deepEqual(result.platform, 'ios');
        assert.deepEqual(result.configXMLPath, path.resolve(iosProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(iosProjPath, 'platforms', 'ios'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect cordova-ios when below platforms/ios/<folder>', function (done) {
      var pathBelowIOS = path.resolve(iosProjPath, 'platforms', 'ios', 'cordova');
      process.chdir(pathBelowIOS);
      iosPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-ios');
        assert.deepEqual(result.platform, 'ios');
        assert.deepEqual(result.configXMLPath, path.resolve(iosProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(iosProjPath, 'platforms', 'ios'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should use folder name where config.xml lives if problem getting Cordova appname from config.xml', function (done) {
      var Fixture = require('ibm-test-fixtures');
      var corrupConfigXMLPath = path.resolve(__dirname, '..', 'fixtures', 'testCordovaProjectCorruptConfigXML.zip');

      //This will be deleted when the after() function runs as it is the same fixture path
      var corruptConfigXMLFixture = new Fixture(corrupConfigXMLPath, fixturePath);
      corruptConfigXMLFixture.clean();
      var iosProjPathAlt = path.resolve(fixturePath, 'testCordovaProjectCorruptConfigXML');
      process.chdir(iosProjPathAlt);
      iosPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'testCordovaProjectCorruptConfigXML');
        assert.deepEqual(result.platformId, 'cordova-ios');
        assert.deepEqual(result.platform, 'ios');
        assert.deepEqual(result.configXMLPath, path.resolve(iosProjPathAlt, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(iosProjPathAlt, 'platforms', 'ios'));
        corruptConfigXMLFixture.delete();
        done();
      }).catch(function (err) {
        corruptConfigXMLFixture.delete();
        done(err);
      });
  }),

  it('should not detect native-ios when outside project', function (done) {
      process.chdir(__dirname);
      iosPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected cordova-ios outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
