/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var iosPlatform = require('../../lib/nativeIOS');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  iosProjPath;

describe('platform-native-ios native-detect', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('IOSNativeProject.zip', fixturePath);

    cordovaProject.clean();
    iosProjPath = path.resolve(fixturePath, 'IOSNativeProject');
  });

  after(function() {
    cordovaProject.delete();
  });
  
  it('should detect native-ios platform at root of project', function (done) {
      process.chdir(iosProjPath);
      iosPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'TestNativeProject');
        assert.deepEqual(result.platformId, 'native-ios');
        assert.deepEqual(result.platform, 'ios');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, iosProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-ios when below root', function (done) {
      var pathBelowIOS = path.resolve(iosProjPath, 'TestNativeProject');
      process.chdir(pathBelowIOS);
      iosPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'TestNativeProject');
        assert.deepEqual(result.platformId, 'native-ios');
        assert.deepEqual(result.platform, 'ios');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, iosProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not detect native-ios when outside project', function (done) {
      process.chdir(__dirname);
      iosPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected native-ios outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
