/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var iosPlatform = require('../../lib/nativeIOS');
var Fixture = require('ibm-test-fixtures');

var fixturePath,
    noVarsFixture,
    iosProjPath;

describe('platform-native-ios test parsing', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    var noVarsPath = path.resolve(__dirname, '..', 'fixtures', 'NativeProjectInfoPlistNoVars.zip');

    noVarsFixture = new Fixture(noVarsPath, fixturePath);
    noVarsFixture.clean();
    iosProjPath = path.resolve(fixturePath, 'NativeProjectInfoPlistNoVars', 'TestNativeProject');
  });

  after(function() {
    noVarsFixture.delete();
  });
  
  it('should parse native-ios platform when provided the root of project, info.plist contains variables', function (done) {
      var varsPath = path.resolve(__dirname, '..', 'fixtures', 'NativeProjectInfoPlistVars.zip');

      var varsFixture = new Fixture(varsPath, fixturePath);
      varsFixture.clean();
      var iosProjPathAlt = path.resolve(fixturePath, 'NativeProjectInfoPlistVars', 'TestNativeProject');
      iosPlatform.parse(iosProjPathAlt)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], '');
        assert.deepEqual(result['app.name'], '');
        assert.deepEqual(result['app.version'], '1.0');
        varsFixture.delete();
        done();
      }).catch(function (err) {
        varsFixture.delete();
        done(err);
      });
  }),

  it('should parse native-ios platform when provided the root of project, Info.plist has no variables', function (done) {
      iosPlatform.parse(iosProjPath)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], 'com.ibm.test');
        assert.deepEqual(result['app.name'], 'TestNativeProject');
        assert.deepEqual(result['app.version'], '1.0');
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not parse native-ios when provided directory other than root', function (done) {
      iosPlatform.parse(__dirname)
      .then(function () {
        assert(false, 'promise should have been rejected');
      }, function (result) {
        assert.deepEqual(result, undefined);
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
