'use strict';

var assert = require('assert');
var path = require('path');
var fs = require('fs');

global.MDO_MAIN_EXTENSIONS_PATH = path.join(__dirname, '../../mdo-cli/node_modules');
global.MDO_CLI_FULL_VERSION = require('../../mfpdev-cli/package.json').version + '_mdo-server-support';

var HOME = process.env[(process.platform === 'win32') ? 'USERPROFILE' : 'HOME'];
var IBM_HOME = path.join(HOME, '.ibm');
var MFP_HOME = path.join(IBM_HOME, 'mobilefirst');
var versionPath = path.join(MFP_HOME, global.MDO_CLI_FULL_VERSION);
var profilePath = path.join(versionPath, 'server_profiles.json');


describe('Test getServerDetails', function () {

  this.timeout(5000);

  before(function(done){
    if (fs.existsSync(profilePath)) {
      try {
        fs.unlinkSync(profilePath);
      }
      catch (err) {
        assert(false, 'cannot delete server_profile.json');
      }
    }
    done();
  });

  after(function(done){
    if (fs.existsSync(profilePath)) {
      try {
        fs.unlinkSync(profilePath);
      }
      catch (err) {
        assert(false, 'cannot delete server_profile.json');
      }
    }
    done();
  });

  it('getServerDetails no profiles exist error', function (done) {
    require('../lib/get-server-details.js') ('', '', '', true)
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (error) {
        assert(
          error.errno === 127,
          'Error code: ' + error.errno
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getServerAndRuntime myprofile does not exist', function (done) {
    require('../lib/get-server-details.js') ('myprofile', '', '', true)
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (error) {
        assert(
          error.errno === 135,
          'Error code: ' + error.errno
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  /*
  it('getServerAndRuntime exist and server details are returned', function (done) {
    require('../lib/get-server-details.js') ()
      .then(function (rsp) {

        console.log(rsp);
        var getMethod = rsp.getRuntimes;
        var methodPromise = getMethod();
        methodPromise.then (function (rsp) {console.log('GOODNESS!! '+JSON.stringify(rsp));},function (err) {console.log('ERROR!! '+err);});

        assert(rsp !== undefined, 'unexpected response object: ' + rsp.body);
        done();

      })
      .fail(function (error) {
        assert(false, error);
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  after(function(done){
    done();
  });
  */



});


