'use strict';

var assert = require('assert');
var path = require('path');
var fs = require('fs');

// Private modules
var server = require('../../mdo-cmd-server/lib/index.js');
global.MDO_MAIN_EXTENSIONS_PATH = path.join(__dirname, '../../mfpdev-cli/node_modules');
global.MDO_CLI_FULL_VERSION = require('../../mfpdev-cli/package.json').version + '_mdo-server-support';

var HOME = process.env[(process.platform === 'win32') ? 'USERPROFILE' : 'HOME'];
var IBM_HOME = path.join(HOME, '.ibm');
var MFP_HOME = path.join(IBM_HOME, 'mobilefirst');
var versionPath = path.join(MFP_HOME, global.MDO_CLI_FULL_VERSION);
var profilePath = path.join(versionPath, 'server_profiles.json');

describe('Test getServerAndRuntime API', function () {
  this.timeout(5000);

  before(function(done){
    if (fs.existsSync(profilePath)) {
      try {
        fs.unlinkSync(profilePath);
      }
      catch (err) {
        assert(false, 'cannot delete server_profile.json');
      }
    }
    done();
  });

  it('getServerAndRuntime no profiles exist error', function (done) {
    require('../lib/getServerAndRuntime') ('', '', '', true)
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (error) {
        assert(
          error.errno === 127,
          'Error code: ' + error.errno
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getServerAndRuntime myprofile does not exist', function (done) {
    require('../lib/getServerAndRuntime') ('myprofile', '', '', true)
      .then(function () {
        assert(false, 'error should have been thrown');
      })
      .fail(function (error) {
        assert(
          error.errno === 135,
          'Error code: ' + error.errno
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getServerAndRuntime cannot connect to server', function (done) {
    server.run(['add', 'remoteserver', '-u', 'http://remoteserver.ibm.com:9080', '-l', 'demo', '-p', 'demo', '-t', '0'])
      .then(function () {
        require('../lib/getServerAndRuntime') ('remoteserver', '', '', true)
          .then(function () {
            assert(false, 'error should have been thrown');
          })
          .fail(function (error) {
            assert(
              error.errno === 121,
              'Error code: ' + error.errno
            );
            done();
          })
          .catch(function (err) {
            done(err);
          });
      })
      .catch(function () {
        done();
      });
  });

  after(function(done){
    if (fs.existsSync(profilePath)) {
      try {
        fs.unlinkSync(profilePath);
      }
      catch (err) {
        assert(false, 'cannot delete server_profile.json');
      }
    }
    done();
  });

});
