/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

var assert = require('assert');
var serverDetails = {"port": 40034};
var fakeFilePath;//path.join(process.cwd(), 'rest-test.zip');

describe('Test All REST Client API Methods -', function () {
  this.timeout(5000);
/*
  before(function(done){
    var fs = require('fs');
    if (!fs.existsSync(fakeFilePath)) {
      try {
        var fP = fs.writeFileSync(fakeFilePath, 'Text to Write');
        //fs.closeSync(fP);
      }
      catch (err) {
        assert(false, 'cannot create: ' + fakeFilePath);
        done(err);
      }
    }
    done();
  });

  after(function(done){
    var fs = require('fs');
    if (fs.existsSync(fakeFilePath)) {
      try {
        fs.unlinkSync(fakeFilePath);
      }
      catch (err) {
        assert(false, 'cannot delete ' + fakeFilePath);
        done(err);
      }
    }
    done();
  });
*/
  it('getRuntimes called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').getRuntimes(
      serverDetails)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getApplications called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').getApplications(
      {"runtime": "mfp", "port": 40034})
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getAdapters called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').getAdapters(
      {"runtime": "mfp", "port": 40034})
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });


  it('registerApplication called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').registerApplication(
      serverDetails, {
        "applicationKey": {
          "bundleId": "com.dummy",
          "version": "2.0",
          "clientPlatform": "ios"
        }
      })
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'HTTPRequestError',
          'The expected error code (HTTPRequestError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getApplicationDescriptor called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').getApplicationDescriptor(
      serverDetails,
        {
          "bundleId": "com.dummy",
          "version": "1.0",
          "clientPlatform": "ios"
        }, fakeFilePath)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('setApplicationDescriptor called and file does not exist', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').setApplicationDescriptor(
      serverDetails, fakeFilePath, {
        "bundleId": "com.dummy",
        "version": "1.0",
        "clientPlatform": "ios"
      })
      .then(function (rsp) {
        assert(false, 'ApplicationDescriptorPushError error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.name === 'ApplicationDescriptorPushError',
          'The expected error code (ApplicationDescriptorPushError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('getRuntimeConfiguration called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').getRuntimeConfiguration(
      serverDetails)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

  it('setRuntimeConfiguration called and server is down', function (done) {
    require('../lib/rest-client-api/rest-client-api.js').setRuntimeConfiguration(
      serverDetails, {
        runtimeConfiguration: {
          productVersion: "8.0.0.00-20151207-0630"
        }
      })
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.jse_cause && error.jse_cause.code === 'HTTPRequestError',
          'The expected error code (HTTPRequestError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });
  });

});
