/*
	Licensed Material - Property of IBM

	(C) Copyright 2015 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


/* globals describe, it */  // make jshint happy

'use strict';
var assert = require('assert');
var path = require('path');
var restserver = null;
var serverRunning = false;
var jsonServer = require('json-server');
var fakeFilePath = path.join(process.cwd(), 'rest-test.zip');

describe('Test All REST Client Methods -', function () {
  // initialized in before()
  var testFileLocation = fakeFilePath;

  before(function(done){
    var fs = require('fs');
    if (!fs.existsSync(fakeFilePath)) {
      try {
        fs.writeFileSync(fakeFilePath, 'Text to Write');
      }
      catch (err) {
        assert(false, 'cannot create: ' + fakeFilePath);
        done(err);
      }
    }
    done();
  });
/*
  after(function(done){
    var fs = require('fs');
    if (fs.existsSync(fakeFilePath)) {
      try {
        fs.unlinkSync(fakeFilePath);
      }
      catch (err) {
        assert(false, 'cannot delete ' + fakeFilePath);
        done(err);
      }
    }
    done();
  });
*/
  it('test get method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').get()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test getFile method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').getFile()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test put method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').put()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test post method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').post()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test postFile method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').postFile()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + JSON.stringify(rsp));
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test delete method - with invalid arguments', function (done) {

    require('../lib/rest-client/rest-client.js').delete()
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + rsp);
        done();
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        //stopServer();
        done(err);
      });

  });
  it('test get method - get called but server is down', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').get('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test post method - post called but server is down', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').post('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000, {})
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test put method - put called but server is down', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').put('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000, {})
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test delete method - delete called but server is down', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').delete('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test getFile method - getFile server but is not running', function (done) {

    //stopServer();
    require('../lib/rest-client/rest-client.js').getFile('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000, testFileLocation)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test postFile method - postFile called but server is not running', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').postFile('localhost', 30034, '/users/1', 'http:', 'jane', 'doe', 5000, testFileLocation)
      .then(function (rsp) {
        assert(false, 'ECONNREFUSED error should have been thrown but received success with a response body of: ' + rsp.body);
      })
      .fail(function (error) {
        assert(
          error.code === 'ECONNREFUSED',
          'The expected error code (ECONNREFUSED) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test postFile method - verify postFile runs with file path', function (done) {

    startServer();

    require('../lib/rest-client/rest-client.js').postFile('localhost', 30033, '/users/1', 'http:', 'jane', 'doe', 5000, testFileLocation)
      .then(function () {
        done();
      })
      .fail(function (error) {
        assert(
          false,
          'Expected a successful result, but recieved an error. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  /*
  it('test getFile method - getFile called but file path is not valid', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').getFile('localhost', 30033, '/users/1', 'http:', 'jane', 'doe', 5000, 'fakeFilePath/this.zip')
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });
  */

  it('test postFile method - postFile called but file path is not valid', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').postFile('localhost', 30033, '/users/1', 'http:', 'jane', 'doe', 5000, '')
      .then(function (rsp) {
        assert(false, 'InvalidArgumentsError error should have been thrown but received response body of: ' + rsp);
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'The expected error code (InvalidArgumentsError) was not returned. Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test delete method - and verify 1 is removed', function (done) {

    startServer();

    require('../lib/rest-client/rest-client.js').delete('localhost', 30033, '/users/1', 'http:', 'jane', 'doe', 5000)
      .then(function () {

        done();
      })
      .fail(function (error) {
        assert(
          false,
          'Expected a successful result, but recieved an error. Received the following error object details: ' + error
        );
        //stopServer();
        done();
      })
      .catch(function (err) {
        //stopServer();
        done(err);
      });

  });

  it('test get method - get called and payload is returned', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').get('localhost', 30033, '/users/2', 'http:', 'jane', 'doe', 5000)
      .then(function (rsp) {
        var tPassed = false;
        if (rsp && rsp.body) {
          var tJObj = JSON.parse(rsp.body);
          if (tJObj.id === 2) {
            tPassed = true;
          }
        }
        assert(tPassed, 'expected to receive a json object containing user 2 info but got: ' + rsp.body);
        done();
      })
      .fail(function (error) {
        assert(
          error && error.name === 'InvalidArgumentsError',
          'Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test post method - post called passing a payload', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').post('localhost', 30033, '/users', 'http:', 'jane', 'doe', 5000, {
      "first_name": "madison",
      "last_name": "doe"
    })
      .then(function () {
        require('../lib/rest-client/rest-client.js').get('localhost', 30033, '/users/3', 'http:', 'jane', 'doe', 5000)
          .then(function (rsp) {
            var tPassed = false;
            if (rsp && rsp.body) {
              var tJObj = JSON.parse(rsp.body);
              if (tJObj.id === 3) {
                tPassed = true;
              }
            }
            assert(tPassed, 'expected to receive a json object containing user 3 info but got: ' + rsp.body);
            done();
          });
      })
      .fail(function (error) {
        assert(
          false,
          'Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  it('test put method - put called passing a payload', function (done) {

    //stopServer();

    require('../lib/rest-client/rest-client.js').put('localhost', 30033, '/users', 'http:', 'jane', 'doe', 5000, {
      "first_name": "madison",
      "last_name": "doe"
    })
      .then(function () {
        require('../lib/rest-client/rest-client.js').get('localhost', 30033, '/users/3', 'http:', 'jane', 'doe', 5000)
          .then(function (rsp) {
            var tPassed = false;
            if (rsp && rsp.body) {
              var tJObj = JSON.parse(rsp.body);
              //console.log(JSON.stringify(tJObj));
              if (tJObj.id === 3) {
                tPassed = true;
              }
            }
            assert(tPassed, 'expected to receive a json object containing user 3 info but got: ' + rsp.body);
            done();
          });
      })
      .fail(function (error) {
        assert(
          false,
          'Received the following error object details: ' + error
        );
        done();
      })
      .catch(function (err) {
        done(err);
      });

  });

  function startServer() {

    if (typeof restserver === 'undefined' || restserver === null) {

      restserver = jsonServer.create();
      var router = jsonServer.router({
        "users": [
          {
            "id": 1,
            "first_name": "john",
            "last_name": "doe"
          },
          {
            "id": 2,
            "first_name": "jane",
            "last_name": "roe"
          }
        ]
      });
      restserver.use(router);
      restserver.listen(30033);
      serverRunning = true;

    }

  }

  /*
   function stopServer() {
   // i am force to implement this way since there is no obvious way to stop a json-server object
   if (typeof restserver !== 'undefined' && restserver !== null) {
   restserver === null;
   }
   }
   */

});
