/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var windowsPlatform = require('../../lib/cordovaWindows8Phone');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
  cordovaProject,
  windowsProjPath;

describe('platform-native-windows detect-cordova windows8phone', function () {
  before(function() {
    fixturePath = path.resolve(__dirname, '..', 'fixtures');
    cordovaProject = getTestFixture('CordovaProject.zip', fixturePath);

    cordovaProject.clean();
    windowsProjPath = path.resolve(fixturePath, 'CordovaProject');
  });

  after(function() {
    cordovaProject.delete();
  });
  
  it('should detect cordova-windowsphone8 platform at root of project', function (done) {
      process.chdir(windowsProjPath);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, path.resolve(windowsProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(windowsProjPath, 'platforms', 'windows'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect cordova-windowsphone8 when below platforms/windows/<folder>', function (done) {
      var pathBelowWindows = path.resolve(windowsProjPath, 'platforms', 'windows', 'cordova');
      process.chdir(pathBelowWindows);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'HelloCordova');
        assert.deepEqual(result.platformId, 'cordova-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, path.resolve(windowsProjPath, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(windowsProjPath, 'platforms', 'windows'));
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should use folder name where config.xml lives if problem getting Cordova appname from config.xml', function (done) {
      var Fixture = require('ibm-test-fixtures');
      var corrupConfigXMLPath = path.resolve(__dirname, '..', 'fixtures', 'testCordovaProjectCorruptConfigXML.zip');

      //This will be deleted when the after() function runs as it is the same fixture path
      var corruptConfigXMLFixture = new Fixture(corrupConfigXMLPath, fixturePath);
      corruptConfigXMLFixture.clean();
      var windowsProjPathAlt = path.resolve(fixturePath, 'testCordovaProjectCorruptConfigXML');
      process.chdir(windowsProjPathAlt);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'testCordovaProjectCorruptConfigXML');
        assert.deepEqual(result.platformId, 'cordova-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, path.resolve(windowsProjPathAlt, 'config.xml'));
        assert.deepEqual(result.platformPath, path.resolve(windowsProjPathAlt, 'platforms', 'windows'));
        corruptConfigXMLFixture.delete();
        done();
      }).catch(function (err) {
        corruptConfigXMLFixture.delete();
        done(err);
      });
  }),

  it('should not detect native-windows when outside project', function (done) {
      process.chdir(__dirname);
      windowsPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected cordova-windowsphone8 outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
