/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var windowsPlatform = require('../../lib/nativeWindows8');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
    nativeProjectFixture,
    windowsProjPath;

describe('platform-native-windows native-detect windows8', function () {
  before(function() {
      fixturePath = path.resolve(__dirname, '..', 'fixtures');
      nativeProjectFixture = getTestFixture('Windows8DesktopOnly.zip', fixturePath);

      nativeProjectFixture.clean();
      windowsProjPath = path.resolve(fixturePath, 'Windows8DesktopOnly');
  });

  after(function() {
    nativeProjectFixture.delete();
  });

  it('should detect native-windows 8 platform at root of project', function (done) {
      process.chdir(windowsProjPath);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'DesktopOnly');
        assert.deepEqual(result.platformId, 'native-windows8');
        assert.deepEqual(result.platform, 'windows8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-windows 8 when below root', function (done) {
      var pathBelowWindows = path.resolve(windowsProjPath, 'Windows8DesktopOnly');
      process.chdir(pathBelowWindows);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'DesktopOnly');
        assert.deepEqual(result.platformId, 'native-windows8');
        assert.deepEqual(result.platform, 'windows8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-windows 8 when further below root', function (done) {
      var pathBelowWindows = path.resolve(windowsProjPath, 'Windows8DesktopOnly', 'bin');
      process.chdir(pathBelowWindows);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'DesktopOnly');
        assert.deepEqual(result.platformId, 'native-windows8');
        assert.deepEqual(result.platform, 'windows8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not detect native-windows when outside project', function (done) {
      process.chdir(__dirname);
      windowsPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected native-windows8 outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
