/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var windowsPlatform = require('../../lib/nativeWindows8Phone');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
    nativeProjectFixture,
    windowsProjPath;

describe('platform-native-windows detect-native windows8phone', function () {
  before(function() {
      fixturePath = path.resolve(__dirname, '..', 'fixtures');
      nativeProjectFixture = getTestFixture('Windows8PhoneOnly.zip', fixturePath);

      nativeProjectFixture.clean();
      windowsProjPath = path.resolve(fixturePath, 'Windows8PhoneOnly');
  });

  after(function() {
    nativeProjectFixture.delete();
  });

  it('should detect native-windows 8 platform at root of project', function (done) {
      process.chdir(windowsProjPath);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'PhoneOnly');
        assert.deepEqual(result.platformId, 'native-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-windows 8 when below root', function (done) {
      var pathBelowWindows = path.resolve(windowsProjPath, 'Windows8PhoneOnly');
      process.chdir(pathBelowWindows);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'PhoneOnly');
        assert.deepEqual(result.platformId, 'native-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should detect native-windows 8 when further below root', function (done) {
      var pathBelowWindows = path.resolve(windowsProjPath, 'Windows8PhoneOnly', 'bin');
      process.chdir(pathBelowWindows);
      windowsPlatform.detect()
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result.appName, 'PhoneOnly');
        assert.deepEqual(result.platformId, 'native-windows8phone');
        assert.deepEqual(result.platform, 'windowsphone8');
        assert.deepEqual(result.configXMLPath, undefined);
        assert.deepEqual(result.platformPath, windowsProjPath);
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not detect native-windows when outside project', function (done) {
      process.chdir(__dirname);
      windowsPlatform.detect()
      .then(function () {
        assert(false, 'It should not have detected native-windowsphone8 outside project');
      }, function () {
        assert(true, 'Should not have detected a project');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
