/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var path = require('path');
//private packages
var windowsPlatform = require('../../lib/nativeWindows8');
var getTestFixture = require('mdo-test-resources');

var fixturePath,
    nativeProjectFixture,
    windowsProjPath;

describe('platform-native-windows test parsing', function () {
  before(function() {
      fixturePath = path.resolve(__dirname, '..', 'fixtures');
      nativeProjectFixture = getTestFixture('Windows8NativeProject.zip', fixturePath);

      nativeProjectFixture.clean();
      windowsProjPath = path.resolve(fixturePath, 'Windows8NativeProject', 'BlankSharedApp1');
  });

  after(function() {
    nativeProjectFixture.delete();
  });

  it('should parse native-windows platform when provided the root of project', function (done) {
      windowsPlatform.parse(windowsProjPath)
      .then(function (result) {
        assert.notEqual(result, undefined);
        assert.deepEqual(result['app.dotId'], 'BlankSharedApp1');
        assert.deepEqual(result['app.name'], 'BlankSharedApp1');
        assert.deepEqual(result['app.version'], '1.0.0.0');
        done();
      }).catch(function (err) {
        done(err);
      });
  }),

  it('should not parse native-windows when provided directory below file', function (done) {
      var windowsProjPathBelow = path.resolve(windowsProjPath, 'BlankSharedApp1', 'DepthBelow');
      windowsPlatform.parse(windowsProjPathBelow)
      .then(function () {
        assert(false, 'promise should have been rejected');
      }, function (result) {
        assert.deepEqual(result, undefined);
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
