/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';
/*jshint -W030 */

var assert = require('assert');
var fs = require('fs');
var path = require('path');
//private packages
var reswAPI = require('../../lib/nativeWindows/process-properties-file/resw-api');
var Fixture = require('ibm-test-fixtures');

var fixturePath,
    reswFixture,
    reswFilesPath,
    reswTemplatePath,
    reswTemplateAlteredPath;

describe('test resw-api', function () {
  before(function() {
      fixturePath = path.resolve(__dirname, '..', 'fixtures');
      var reswFilesFixturePath = path.resolve(__dirname, '..', 'fixtures', 'reswFiles.zip');
      reswFixture = new Fixture(reswFilesFixturePath, fixturePath);

      reswFixture.clean();
      reswFilesPath = path.resolve(fixturePath, 'reswFiles');
      reswTemplatePath = path.resolve(reswFilesPath, 'mfpclient-template.resw');
      reswTemplateAlteredPath = path.resolve(reswFilesPath, 'mfpclient-template-altered.resw');
  });

  after(function() {
    reswFixture.delete();
  });
  
  it('should load the xml parsed object and get and set properties', function (done) {
      new reswAPI(reswTemplatePath)
      .then(function (reswObj) {
        assert.notDeepEqual(reswObj, undefined, 'resw api object should not be undefined');
        assert.deepEqual(reswObj.getDataEntry('wlServerProtocol'), 'http');
        assert.deepEqual(reswObj.getDataEntry('wlServerHost'), '9.27.93.23');
        assert.deepEqual(reswObj.getDataEntry('wlServerPort'), '9080');
        assert.deepEqual(reswObj.getDataEntry('wlServerContext'), '/mfp/');
        assert.deepEqual(reswObj.getDataEntry('languagePreferences'), 'en');
        assert.deepEqual(reswObj.getDataEntry('wlAppId'), '');
        assert.deepEqual(reswObj.getDataEntry('nonExistent'), undefined);
        //Set some stuff
        assert.deepEqual(reswObj.setDataEntry('wlServerProtocol', 'https'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('wlServerHost', '1.2.3.4'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('wlServerPort', '10080'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('wlServerContext', '/altRuntime/'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('languagePreferences', 'fr'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('wlAppId', 'myAppId'), true, 'successful set should return true');
        assert.deepEqual(reswObj.setDataEntry('nonExistent', 'something'), false, 'setting property thats doesnt exist returns false');
        //Get the stuff we set
        assert.deepEqual(reswObj.getDataEntry('wlServerProtocol'), 'https');
        assert.deepEqual(reswObj.getDataEntry('wlServerHost'), '1.2.3.4');
        assert.deepEqual(reswObj.getDataEntry('wlServerPort'), '10080');
        assert.deepEqual(reswObj.getDataEntry('wlServerContext'), '/altRuntime/');
        assert.deepEqual(reswObj.getDataEntry('languagePreferences'), 'fr');
        assert.deepEqual(reswObj.getDataEntry('wlAppId'), 'myAppId');
        assert.deepEqual(reswObj.getDataEntry('nonExistent'), undefined);
        //Write it to same location
        reswObj.writeFile();

        var file1 = fs.readFileSync(reswTemplatePath, {encoding:'utf8'}).trim();
        var file2 = fs.readFileSync(reswTemplateAlteredPath, {encoding:'utf8'}).trim();

        assert.deepEqual(file1, file2, 'files should be equal now that we set the values');
        done();
      }).catch(function (err) {
        done(err);
      });
  });
});
