/*
	Licensed Material - Property of IBM

	(C) Copyright 2015,2016 IBM Corp.

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/


'use strict';

var assert = require('assert');
var path = require('path');

describe('contributed platform sanity check', function() {
  var platformExtensions;

  before(function() {
    var pluggington = require('pluggington');
    var allExtensions = pluggington._getAllExtensions(path.resolve(__dirname, '..', '..'));
    platformExtensions = allExtensions['mdo.platforms'];
  });

  it('should find some contributed platforms', function() {
    assert.notEqual(platformExtensions, undefined, 'I did not find any contributed platforms.');
    assert.notEqual(platformExtensions.length, 0, 'I did not find any contributed platforms.');
  });

  it('all platforms should have a name', function() {
    platformExtensions.forEach(function(extension) {
      var path = extension._path;

      assert.notEqual(extension.name, undefined, 'platform extension at ' + path + ' does not specify a name!');
      assert.notEqual(extension.name, "", 'platform extension at ' + path + ' has an empty name!');
    });
  });

  it('all platforms should have a unique id', function() {
    var ids = {};

    platformExtensions.forEach(function(extension) {
      var path = extension._path;

      assert.notEqual(extension.id, undefined, 'platform extension at ' + path + ' does not specify an id!');
      assert.notEqual(extension.id, "", 'platform extension at ' + path + ' has an empty id!');

      if (ids[extension.id]) {
        assert(false, 'platform extension id=' + extension.id + ' defined at ' + path + ' uses the same id as another platform defined in ' + ids[extension.id]);
      } else {
        ids[extension.id] = path;
      }
    });
  });

  it('all platforms should export a parse function', function() {
    platformExtensions.forEach(function(extension) {
      var path = extension._path;

      assert.notEqual(extension.export.parse, undefined, 'platform extension at ' + path + ' does not export a parse function!');
    });
  });

  it('all platforms should export a detect function', function() {
    platformExtensions.forEach(function(extension) {
      var path = extension._path;

      assert.notEqual(extension.export.detect, undefined, 'platform extension at ' + path + ' does not export a detect function!');
    });
  });
});
